@@ -32,8 +32,14 @@ $ lookmlhelper ds-data-solutions-gbq dimensions-ai.data_analytics.clinical_trial
     help=
     'DATASET: a fully scopes GBQ dataset eg `dimensions-ai.data_analytics.clinical_trials`.'
 )
+@click.option(
+    '--exclude',
+    '-e',
+    help=
+    'EXCLUDE: fields to be excluded from the extraction e.g. "date, name, category"'
+)
 @click.pass_context
-def main_cli(ctx, billproject=None, dataset=None, examples=False):
+def main_cli(ctx, billproject=None, dataset=None, exclude=None, examples=False):
     """LOOKML-HELPER CLI.
 Requires both a billproject and dataset to run. 
     """
@@ -43,9 +49,13 @@ Requires both a billproject and dataset to run.
         return
 
     if (billproject and dataset):
+        exclude_fields = None
+        if exclude:
+            exclude_fields = [x.strip() for x in exclude.split(",")]
         run_gbq_extraction(
             gbq_billing_project=billproject,
             gbq_dataset=dataset,
+            exclude_field_paths = exclude_fields,
         )
 
     else:
